@@ -772,7 +772,7 @@ gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 	case CD_DEVICE_KIND_PRINTER:
 		/* TRANSLATORS: this is the final summary */
 		gcm_calib_add_page_para (content, _("The printer has been calibrated successfully."));
-		gcm_calib_add_page_para (content, _("Docments printed from this device will be color managed."));
+		gcm_calib_add_page_para (content, _("Documents printed from this device will be color managed."));
 		break;
 	default:
 		/* TRANSLATORS: this is the final summary */
@@ -2072,7 +2072,7 @@ gcm_calib_image_changed_cb (GcmCalibrate *calibrate,
 {
 	gchar *path;
 	GdkPixbuf *pixbuf;
-	GError *error;
+	GError *error = NULL;
 
 	if (filename != NULL) {
 		path = g_build_filename (GCM_DATA, "icons", filename, NULL);
